Function read_process_memory::copy_address [−][src]
pub fn copy_address<T>(
addr: usize,
length: usize,
source: &T
) -> Result<Vec<u8>> where
T: CopyAddress, Expand description
Copy length bytes of memory at addr from source.
This is just a convenient way to call CopyAddress::copy_address without
having to provide your own buffer.