CopyAddress

Trait CopyAddress 

pub trait CopyAddress {
    // Required method
    fn copy_address(&self, addr: usize, buf: &mut [u8]) -> Result<()>;
}
A trait that provides a method for reading memory from another process.

Required Methods

fn copy_address(&self, addr: usize, buf: &mut [u8]) -> Result<()>

Try to copy buf.len() bytes from addr in the process self, placing them in buf.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors