pub trait CopyAddress { fn copy_address(&self, addr: usize, buf: &mut [u8]) -> Result<()>; }
A trait that provides a method for reading memory from another process.
Try to copy buf.len() bytes from addr in the process self, placing them in buf.
buf.len()
addr
self
buf